/* Fesslix - Stochastic Analysis
 * Copyright (C) 2010-2017 Wolfgang Betz
 *
 * Fesslix is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Fesslix is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Fesslix.  If not, see <http://www.gnu.org/licenses/>. 
 */

#include "fesslix.h"
#include <iostream>

#include "user_code.h"



int main(int argc, char** argv)
{
  try {
    // some global settings of Fesslix
      GlobalVar.set_exe_dir(argv[0]);	// set path of executable (optional)
      GlobalVar.logLevel=3;		// the log-level to 3 (optional)
    // create the Fesslix engine
      if (flxengine_init()>0) return RETURN_ERROR;
      #ifdef __WINDOWS__
	fesslix_pauseAtEnd = true;	// enforce a pause at end (optional)
      #endif
      
    std::cout << "Hello world!" << std::endl;
    
    cdf_example();
    
    rv_def();
    
    mci_simu();
    
    sus_simu();

      
    std::cout << "Good night!" << std::endl;
      
    // unload the engine
      flxengine_unload();
      flx_delete_FLXcout();
      if (fesslix_pauseAtEnd) { flx_take_a_break(); }
  }
    catch ( FlxException &e) {
    FLXMSG("main_4",1);
    *(GlobalVar.get_true_cerr()) << std::endl << e.what() << std::endl;
    GlobalVar.logLevel_strong_reset();
    if (GlobalVar.check_logNOTcout()) {
      GlobalVar.slog(1) << std::endl << e.what() << std::endl;
      flx_print_RETURN_ERROR();
    }
    flxengine_unload();
    flx_delete_FLXcout();
    if (fesslix_pauseAtEnd) { flx_take_a_break(); }
    return RETURN_ERROR;
  }
  catch (std::exception const &e) {
    FLXMSG("main_5",1);
    *(GlobalVar.get_true_cerr()) << std::endl << "ERROR: Whoops, something went wrong: " << e.what() << std::endl;
    GlobalVar.logLevel_strong_reset();
    if (GlobalVar.check_logNOTcout()) {
      GlobalVar.slog(1) << std::endl << "ERROR: Whoops, something went wrong: " << e.what() << std::endl;
      flx_print_RETURN_ERROR();
    }
    flxengine_unload();
    flx_delete_FLXcout();
    if (fesslix_pauseAtEnd) { flx_take_a_break(); }
    return RETURN_ERROR;
  }
  catch(...) { 
    FLXMSG("main_6",1);
    *(GlobalVar.get_true_cerr()) << std::endl << "ERROR: whoops!" << std::endl; 
    GlobalVar.logLevel_strong_reset();
    if (GlobalVar.check_logNOTcout()) {
      GlobalVar.slog(1) << std::endl << "ERROR: whoops!" << std::endl; 
      flx_print_RETURN_ERROR();
    }
    flxengine_unload();
    flx_delete_FLXcout();
    if (fesslix_pauseAtEnd) { flx_take_a_break(); }
    return RETURN_ERROR;
  }
}


